require "dnkey/version"
require 'dnsruby'
require 'pry'
include Dnsruby

module Dnkey
  def self.default_options
    {:nameservers => ['8.8.8.8']}
  end

  class API
    def self.get(domain, options=Dnkey::default_options)
      keys = get_txt_entries(domain, options).answer.find_all do |answer|
        value = answer.strings.first
        value.include? "dnkey-#{options[:key].to_s}"
      end
      keys.map.each {|key| key.rdata.first.split('=').last.strip}
    end

    def self.get_all(domain, options=Dnkey::default_options)
      keys = get_txt_entries(domain, options).answer.find_all do |answer|
        value = answer.strings.first
        value.include? "dnkey-"
      end
      result = {}
      keys.each do |key|
        entry = key.rdata.first.split('=')
        result[entry.first.gsub('dnkey-','').to_sym] ||= []
        result[entry.first.gsub('dnkey-','').to_sym] << entry.last.strip
      end
      result
    end

    private

    def self.get_txt_entries(domain, options)
      res = Dnsruby::Resolver.new(nameservers: options[:nameservers])
      ret = res.query(domain, Types.TXT)
    end
  end

  # TODO: refactor out the duplication
  class Bitcoin
    def self.get(domain, options={})
      API.get(domain, {:key => :btc}.merge(options).merge(Dnkey::default_options))
    end
  end

  class Litecoin
    def self.get(domain, options={})
      API.get(domain, {:key => :lite}.merge(options).merge(Dnkey::default_options))
    end
  end

  class Dogecoin
    def self.get(domain, options={})
      API.get(domain, {:key => :doge}.merge(options).merge(Dnkey::default_options))
    end
  end

  class Dashcoin
    def self.get(domain, options={})
      API.get(domain, {:key => :dash}.merge(options).merge(Dnkey::default_options))
    end
  end

  class Email
    def self.get(domain, options={})
      API.get(domain, {:key => :email}.merge(options).merge(Dnkey::default_options))
    end
  end

end
